"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeInstanceXAdvancedMachineFeatures(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_NESTED_VIRTUALIZATION_FIELD_NUMBER: builtins.int
    THREADS_PER_CORE_FIELD_NUMBER: builtins.int
    enable_nested_virtualization: builtins.bool
    threads_per_core: builtins.float
    def __init__(
        self,
        *,
        enable_nested_virtualization: builtins.bool = ...,
        threads_per_core: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_nested_virtualization", b"enable_nested_virtualization", "threads_per_core", b"threads_per_core"]) -> None: ...

global___ComputeInstanceXAdvancedMachineFeatures = ComputeInstanceXAdvancedMachineFeatures

@typing_extensions.final
class ComputeInstanceXAttachedDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEVICE_NAME_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_KEY_RAW_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_KEY_SHA256_FIELD_NUMBER: builtins.int
    KMS_KEY_SELF_LINK_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    device_name: builtins.str
    disk_encryption_key_raw: builtins.str
    disk_encryption_key_sha256: builtins.str
    kms_key_self_link: builtins.str
    mode: builtins.str
    source: builtins.str
    def __init__(
        self,
        *,
        device_name: builtins.str = ...,
        disk_encryption_key_raw: builtins.str = ...,
        disk_encryption_key_sha256: builtins.str = ...,
        kms_key_self_link: builtins.str = ...,
        mode: builtins.str = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["device_name", b"device_name", "disk_encryption_key_raw", b"disk_encryption_key_raw", "disk_encryption_key_sha256", b"disk_encryption_key_sha256", "kms_key_self_link", b"kms_key_self_link", "mode", b"mode", "source", b"source"]) -> None: ...

global___ComputeInstanceXAttachedDisk = ComputeInstanceXAttachedDisk

@typing_extensions.final
class ComputeInstanceXBootDiskXInitializeParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    image: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    size: builtins.float
    type: builtins.str
    def __init__(
        self,
        *,
        image: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        size: builtins.float = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image", b"image", "labels", b"labels", "size", b"size", "type", b"type"]) -> None: ...

global___ComputeInstanceXBootDiskXInitializeParams = ComputeInstanceXBootDiskXInitializeParams

@typing_extensions.final
class ComputeInstanceXBootDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_DELETE_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_KEY_RAW_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_KEY_SHA256_FIELD_NUMBER: builtins.int
    KMS_KEY_SELF_LINK_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    INITIALIZE_PARAMS_FIELD_NUMBER: builtins.int
    auto_delete: builtins.bool
    device_name: builtins.str
    disk_encryption_key_raw: builtins.str
    disk_encryption_key_sha256: builtins.str
    kms_key_self_link: builtins.str
    mode: builtins.str
    source: builtins.str
    @property
    def initialize_params(self) -> global___ComputeInstanceXBootDiskXInitializeParams: ...
    def __init__(
        self,
        *,
        auto_delete: builtins.bool = ...,
        device_name: builtins.str = ...,
        disk_encryption_key_raw: builtins.str = ...,
        disk_encryption_key_sha256: builtins.str = ...,
        kms_key_self_link: builtins.str = ...,
        mode: builtins.str = ...,
        source: builtins.str = ...,
        initialize_params: global___ComputeInstanceXBootDiskXInitializeParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["initialize_params", b"initialize_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete", b"auto_delete", "device_name", b"device_name", "disk_encryption_key_raw", b"disk_encryption_key_raw", "disk_encryption_key_sha256", b"disk_encryption_key_sha256", "initialize_params", b"initialize_params", "kms_key_self_link", b"kms_key_self_link", "mode", b"mode", "source", b"source"]) -> None: ...

global___ComputeInstanceXBootDisk = ComputeInstanceXBootDisk

@typing_extensions.final
class ComputeInstanceXConfidentialInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_CONFIDENTIAL_COMPUTE_FIELD_NUMBER: builtins.int
    enable_confidential_compute: builtins.bool
    def __init__(
        self,
        *,
        enable_confidential_compute: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_confidential_compute", b"enable_confidential_compute"]) -> None: ...

global___ComputeInstanceXConfidentialInstanceConfig = ComputeInstanceXConfidentialInstanceConfig

@typing_extensions.final
class ComputeInstanceXNetworkInterfaceXAccessConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAT_IP_FIELD_NUMBER: builtins.int
    NETWORK_TIER_FIELD_NUMBER: builtins.int
    PUBLIC_PTR_DOMAIN_NAME_FIELD_NUMBER: builtins.int
    nat_ip: builtins.str
    network_tier: builtins.str
    public_ptr_domain_name: builtins.str
    def __init__(
        self,
        *,
        nat_ip: builtins.str = ...,
        network_tier: builtins.str = ...,
        public_ptr_domain_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nat_ip", b"nat_ip", "network_tier", b"network_tier", "public_ptr_domain_name", b"public_ptr_domain_name"]) -> None: ...

global___ComputeInstanceXNetworkInterfaceXAccessConfig = ComputeInstanceXNetworkInterfaceXAccessConfig

@typing_extensions.final
class ComputeInstanceXNetworkInterfaceXAliasIpRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_CIDR_RANGE_FIELD_NUMBER: builtins.int
    SUBNETWORK_RANGE_NAME_FIELD_NUMBER: builtins.int
    ip_cidr_range: builtins.str
    subnetwork_range_name: builtins.str
    def __init__(
        self,
        *,
        ip_cidr_range: builtins.str = ...,
        subnetwork_range_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_cidr_range", b"ip_cidr_range", "subnetwork_range_name", b"subnetwork_range_name"]) -> None: ...

global___ComputeInstanceXNetworkInterfaceXAliasIpRange = ComputeInstanceXNetworkInterfaceXAliasIpRange

@typing_extensions.final
class ComputeInstanceXNetworkInterfaceXIpv6AccessConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_IPV6_FIELD_NUMBER: builtins.int
    EXTERNAL_IPV6_PREFIX_LENGTH_FIELD_NUMBER: builtins.int
    NETWORK_TIER_FIELD_NUMBER: builtins.int
    PUBLIC_PTR_DOMAIN_NAME_FIELD_NUMBER: builtins.int
    external_ipv6: builtins.str
    external_ipv6_prefix_length: builtins.str
    network_tier: builtins.str
    public_ptr_domain_name: builtins.str
    def __init__(
        self,
        *,
        external_ipv6: builtins.str = ...,
        external_ipv6_prefix_length: builtins.str = ...,
        network_tier: builtins.str = ...,
        public_ptr_domain_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["external_ipv6", b"external_ipv6", "external_ipv6_prefix_length", b"external_ipv6_prefix_length", "network_tier", b"network_tier", "public_ptr_domain_name", b"public_ptr_domain_name"]) -> None: ...

global___ComputeInstanceXNetworkInterfaceXIpv6AccessConfig = ComputeInstanceXNetworkInterfaceXIpv6AccessConfig

@typing_extensions.final
class ComputeInstanceXNetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPV6_ACCESS_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NETWORK_IP_FIELD_NUMBER: builtins.int
    NIC_TYPE_FIELD_NUMBER: builtins.int
    QUEUE_COUNT_FIELD_NUMBER: builtins.int
    STACK_TYPE_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    SUBNETWORK_PROJECT_FIELD_NUMBER: builtins.int
    ACCESS_CONFIG_FIELD_NUMBER: builtins.int
    ALIAS_IP_RANGE_FIELD_NUMBER: builtins.int
    IPV6_ACCESS_CONFIG_FIELD_NUMBER: builtins.int
    ipv6_access_type: builtins.str
    name: builtins.str
    network: builtins.str
    network_ip: builtins.str
    nic_type: builtins.str
    queue_count: builtins.float
    stack_type: builtins.str
    subnetwork: builtins.str
    subnetwork_project: builtins.str
    @property
    def access_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceXNetworkInterfaceXAccessConfig]: ...
    @property
    def alias_ip_range(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceXNetworkInterfaceXAliasIpRange]: ...
    @property
    def ipv6_access_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceXNetworkInterfaceXIpv6AccessConfig]: ...
    def __init__(
        self,
        *,
        ipv6_access_type: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        network_ip: builtins.str = ...,
        nic_type: builtins.str = ...,
        queue_count: builtins.float = ...,
        stack_type: builtins.str = ...,
        subnetwork: builtins.str = ...,
        subnetwork_project: builtins.str = ...,
        access_config: collections.abc.Iterable[global___ComputeInstanceXNetworkInterfaceXAccessConfig] | None = ...,
        alias_ip_range: collections.abc.Iterable[global___ComputeInstanceXNetworkInterfaceXAliasIpRange] | None = ...,
        ipv6_access_config: collections.abc.Iterable[global___ComputeInstanceXNetworkInterfaceXIpv6AccessConfig] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_config", b"access_config", "alias_ip_range", b"alias_ip_range", "ipv6_access_config", b"ipv6_access_config", "ipv6_access_type", b"ipv6_access_type", "name", b"name", "network", b"network", "network_ip", b"network_ip", "nic_type", b"nic_type", "queue_count", b"queue_count", "stack_type", b"stack_type", "subnetwork", b"subnetwork", "subnetwork_project", b"subnetwork_project"]) -> None: ...

global___ComputeInstanceXNetworkInterface = ComputeInstanceXNetworkInterface

@typing_extensions.final
class ComputeInstanceXReservationAffinityXSpecificReservation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "values", b"values"]) -> None: ...

global___ComputeInstanceXReservationAffinityXSpecificReservation = ComputeInstanceXReservationAffinityXSpecificReservation

@typing_extensions.final
class ComputeInstanceXReservationAffinity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    SPECIFIC_RESERVATION_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def specific_reservation(self) -> global___ComputeInstanceXReservationAffinityXSpecificReservation: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        specific_reservation: global___ComputeInstanceXReservationAffinityXSpecificReservation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["specific_reservation", b"specific_reservation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["specific_reservation", b"specific_reservation", "type", b"type"]) -> None: ...

global___ComputeInstanceXReservationAffinity = ComputeInstanceXReservationAffinity

@typing_extensions.final
class ComputeInstanceXSchedulingXNodeAffinities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    key: builtins.str
    operator: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        operator: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "operator", b"operator", "values", b"values"]) -> None: ...

global___ComputeInstanceXSchedulingXNodeAffinities = ComputeInstanceXSchedulingXNodeAffinities

@typing_extensions.final
class ComputeInstanceXScheduling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTOMATIC_RESTART_FIELD_NUMBER: builtins.int
    INSTANCE_TERMINATION_ACTION_FIELD_NUMBER: builtins.int
    MIN_NODE_CPUS_FIELD_NUMBER: builtins.int
    ON_HOST_MAINTENANCE_FIELD_NUMBER: builtins.int
    PREEMPTIBLE_FIELD_NUMBER: builtins.int
    PROVISIONING_MODEL_FIELD_NUMBER: builtins.int
    NODE_AFFINITIES_FIELD_NUMBER: builtins.int
    automatic_restart: builtins.bool
    instance_termination_action: builtins.str
    min_node_cpus: builtins.float
    on_host_maintenance: builtins.str
    preemptible: builtins.bool
    provisioning_model: builtins.str
    @property
    def node_affinities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceXSchedulingXNodeAffinities]: ...
    def __init__(
        self,
        *,
        automatic_restart: builtins.bool = ...,
        instance_termination_action: builtins.str = ...,
        min_node_cpus: builtins.float = ...,
        on_host_maintenance: builtins.str = ...,
        preemptible: builtins.bool = ...,
        provisioning_model: builtins.str = ...,
        node_affinities: collections.abc.Iterable[global___ComputeInstanceXSchedulingXNodeAffinities] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["automatic_restart", b"automatic_restart", "instance_termination_action", b"instance_termination_action", "min_node_cpus", b"min_node_cpus", "node_affinities", b"node_affinities", "on_host_maintenance", b"on_host_maintenance", "preemptible", b"preemptible", "provisioning_model", b"provisioning_model"]) -> None: ...

global___ComputeInstanceXScheduling = ComputeInstanceXScheduling

@typing_extensions.final
class ComputeInstanceXScratchDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTERFACE_FIELD_NUMBER: builtins.int
    interface: builtins.str
    def __init__(
        self,
        *,
        interface: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interface", b"interface"]) -> None: ...

global___ComputeInstanceXScratchDisk = ComputeInstanceXScratchDisk

@typing_extensions.final
class ComputeInstanceXServiceAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAIL_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    email: builtins.str
    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        email: builtins.str = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email", b"email", "scopes", b"scopes"]) -> None: ...

global___ComputeInstanceXServiceAccount = ComputeInstanceXServiceAccount

@typing_extensions.final
class ComputeInstanceXShieldedInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_INTEGRITY_MONITORING_FIELD_NUMBER: builtins.int
    ENABLE_SECURE_BOOT_FIELD_NUMBER: builtins.int
    ENABLE_VTPM_FIELD_NUMBER: builtins.int
    enable_integrity_monitoring: builtins.bool
    enable_secure_boot: builtins.bool
    enable_vtpm: builtins.bool
    def __init__(
        self,
        *,
        enable_integrity_monitoring: builtins.bool = ...,
        enable_secure_boot: builtins.bool = ...,
        enable_vtpm: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_integrity_monitoring", b"enable_integrity_monitoring", "enable_secure_boot", b"enable_secure_boot", "enable_vtpm", b"enable_vtpm"]) -> None: ...

global___ComputeInstanceXShieldedInstanceConfig = ComputeInstanceXShieldedInstanceConfig

@typing_extensions.final
class ComputeInstanceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeInstanceXTimeouts = ComputeInstanceXTimeouts

@typing_extensions.final
class ComputeInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class GuestAcceleratorEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ALLOW_STOPPING_FOR_UPDATE_FIELD_NUMBER: builtins.int
    CAN_IP_FORWARD_FIELD_NUMBER: builtins.int
    CPU_PLATFORM_FIELD_NUMBER: builtins.int
    CURRENT_STATUS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESIRED_STATUS_FIELD_NUMBER: builtins.int
    ENABLE_DISPLAY_FIELD_NUMBER: builtins.int
    GUEST_ACCELERATOR_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    LABEL_FINGERPRINT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    METADATA_FINGERPRINT_FIELD_NUMBER: builtins.int
    METADATA_STARTUP_SCRIPT_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_POLICIES_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TAGS_FINGERPRINT_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    ADVANCED_MACHINE_FEATURES_FIELD_NUMBER: builtins.int
    ATTACHED_DISK_FIELD_NUMBER: builtins.int
    BOOT_DISK_FIELD_NUMBER: builtins.int
    CONFIDENTIAL_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACE_FIELD_NUMBER: builtins.int
    RESERVATION_AFFINITY_FIELD_NUMBER: builtins.int
    SCHEDULING_FIELD_NUMBER: builtins.int
    SCRATCH_DISK_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SHIELDED_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    allow_stopping_for_update: builtins.bool
    can_ip_forward: builtins.bool
    cpu_platform: builtins.str
    current_status: builtins.str
    deletion_protection: builtins.bool
    description: builtins.str
    desired_status: builtins.str
    enable_display: builtins.bool
    @property
    def guest_accelerator(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    hostname: builtins.str
    id: builtins.str
    instance_id: builtins.str
    label_fingerprint: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    machine_type: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    metadata_fingerprint: builtins.str
    metadata_startup_script: builtins.str
    min_cpu_platform: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def resource_policies(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    self_link: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    tags_fingerprint: builtins.str
    zone: builtins.str
    @property
    def advanced_machine_features(self) -> global___ComputeInstanceXAdvancedMachineFeatures: ...
    @property
    def attached_disk(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceXAttachedDisk]: ...
    @property
    def boot_disk(self) -> global___ComputeInstanceXBootDisk: ...
    @property
    def confidential_instance_config(self) -> global___ComputeInstanceXConfidentialInstanceConfig: ...
    @property
    def network_interface(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceXNetworkInterface]: ...
    @property
    def reservation_affinity(self) -> global___ComputeInstanceXReservationAffinity: ...
    @property
    def scheduling(self) -> global___ComputeInstanceXScheduling: ...
    @property
    def scratch_disk(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceXScratchDisk]: ...
    @property
    def service_account(self) -> global___ComputeInstanceXServiceAccount: ...
    @property
    def shielded_instance_config(self) -> global___ComputeInstanceXShieldedInstanceConfig: ...
    @property
    def timeouts(self) -> global___ComputeInstanceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        allow_stopping_for_update: builtins.bool = ...,
        can_ip_forward: builtins.bool = ...,
        cpu_platform: builtins.str = ...,
        current_status: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
        description: builtins.str = ...,
        desired_status: builtins.str = ...,
        enable_display: builtins.bool = ...,
        guest_accelerator: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        hostname: builtins.str = ...,
        id: builtins.str = ...,
        instance_id: builtins.str = ...,
        label_fingerprint: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        machine_type: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        metadata_fingerprint: builtins.str = ...,
        metadata_startup_script: builtins.str = ...,
        min_cpu_platform: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        resource_policies: collections.abc.Iterable[builtins.str] | None = ...,
        self_link: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        tags_fingerprint: builtins.str = ...,
        zone: builtins.str = ...,
        advanced_machine_features: global___ComputeInstanceXAdvancedMachineFeatures | None = ...,
        attached_disk: collections.abc.Iterable[global___ComputeInstanceXAttachedDisk] | None = ...,
        boot_disk: global___ComputeInstanceXBootDisk | None = ...,
        confidential_instance_config: global___ComputeInstanceXConfidentialInstanceConfig | None = ...,
        network_interface: collections.abc.Iterable[global___ComputeInstanceXNetworkInterface] | None = ...,
        reservation_affinity: global___ComputeInstanceXReservationAffinity | None = ...,
        scheduling: global___ComputeInstanceXScheduling | None = ...,
        scratch_disk: collections.abc.Iterable[global___ComputeInstanceXScratchDisk] | None = ...,
        service_account: global___ComputeInstanceXServiceAccount | None = ...,
        shielded_instance_config: global___ComputeInstanceXShieldedInstanceConfig | None = ...,
        timeouts: global___ComputeInstanceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["advanced_machine_features", b"advanced_machine_features", "boot_disk", b"boot_disk", "confidential_instance_config", b"confidential_instance_config", "reservation_affinity", b"reservation_affinity", "resource_info", b"resource_info", "scheduling", b"scheduling", "service_account", b"service_account", "shielded_instance_config", b"shielded_instance_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["advanced_machine_features", b"advanced_machine_features", "allow_stopping_for_update", b"allow_stopping_for_update", "attached_disk", b"attached_disk", "boot_disk", b"boot_disk", "can_ip_forward", b"can_ip_forward", "confidential_instance_config", b"confidential_instance_config", "cpu_platform", b"cpu_platform", "current_status", b"current_status", "deletion_protection", b"deletion_protection", "description", b"description", "desired_status", b"desired_status", "enable_display", b"enable_display", "guest_accelerator", b"guest_accelerator", "hostname", b"hostname", "id", b"id", "instance_id", b"instance_id", "label_fingerprint", b"label_fingerprint", "labels", b"labels", "machine_type", b"machine_type", "metadata", b"metadata", "metadata_fingerprint", b"metadata_fingerprint", "metadata_startup_script", b"metadata_startup_script", "min_cpu_platform", b"min_cpu_platform", "name", b"name", "network_interface", b"network_interface", "project", b"project", "reservation_affinity", b"reservation_affinity", "resource_info", b"resource_info", "resource_policies", b"resource_policies", "scheduling", b"scheduling", "scratch_disk", b"scratch_disk", "self_link", b"self_link", "service_account", b"service_account", "shielded_instance_config", b"shielded_instance_config", "tags", b"tags", "tags_fingerprint", b"tags_fingerprint", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeInstance = ComputeInstance

@typing_extensions.final
class ComputeInstanceFromTemplateXAdvancedMachineFeatures(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_NESTED_VIRTUALIZATION_FIELD_NUMBER: builtins.int
    THREADS_PER_CORE_FIELD_NUMBER: builtins.int
    enable_nested_virtualization: builtins.bool
    threads_per_core: builtins.float
    def __init__(
        self,
        *,
        enable_nested_virtualization: builtins.bool = ...,
        threads_per_core: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_nested_virtualization", b"enable_nested_virtualization", "threads_per_core", b"threads_per_core"]) -> None: ...

global___ComputeInstanceFromTemplateXAdvancedMachineFeatures = ComputeInstanceFromTemplateXAdvancedMachineFeatures

@typing_extensions.final
class ComputeInstanceFromTemplateXBootDiskXInitializeParams(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    image: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    size: builtins.float
    type: builtins.str
    def __init__(
        self,
        *,
        image: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        size: builtins.float = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image", b"image", "labels", b"labels", "size", b"size", "type", b"type"]) -> None: ...

global___ComputeInstanceFromTemplateXBootDiskXInitializeParams = ComputeInstanceFromTemplateXBootDiskXInitializeParams

@typing_extensions.final
class ComputeInstanceFromTemplateXBootDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_DELETE_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_KEY_RAW_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_KEY_SHA256_FIELD_NUMBER: builtins.int
    KMS_KEY_SELF_LINK_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    INITIALIZE_PARAMS_FIELD_NUMBER: builtins.int
    auto_delete: builtins.bool
    device_name: builtins.str
    disk_encryption_key_raw: builtins.str
    disk_encryption_key_sha256: builtins.str
    kms_key_self_link: builtins.str
    mode: builtins.str
    source: builtins.str
    @property
    def initialize_params(self) -> global___ComputeInstanceFromTemplateXBootDiskXInitializeParams: ...
    def __init__(
        self,
        *,
        auto_delete: builtins.bool = ...,
        device_name: builtins.str = ...,
        disk_encryption_key_raw: builtins.str = ...,
        disk_encryption_key_sha256: builtins.str = ...,
        kms_key_self_link: builtins.str = ...,
        mode: builtins.str = ...,
        source: builtins.str = ...,
        initialize_params: global___ComputeInstanceFromTemplateXBootDiskXInitializeParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["initialize_params", b"initialize_params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete", b"auto_delete", "device_name", b"device_name", "disk_encryption_key_raw", b"disk_encryption_key_raw", "disk_encryption_key_sha256", b"disk_encryption_key_sha256", "initialize_params", b"initialize_params", "kms_key_self_link", b"kms_key_self_link", "mode", b"mode", "source", b"source"]) -> None: ...

global___ComputeInstanceFromTemplateXBootDisk = ComputeInstanceFromTemplateXBootDisk

@typing_extensions.final
class ComputeInstanceFromTemplateXConfidentialInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_CONFIDENTIAL_COMPUTE_FIELD_NUMBER: builtins.int
    enable_confidential_compute: builtins.bool
    def __init__(
        self,
        *,
        enable_confidential_compute: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_confidential_compute", b"enable_confidential_compute"]) -> None: ...

global___ComputeInstanceFromTemplateXConfidentialInstanceConfig = ComputeInstanceFromTemplateXConfidentialInstanceConfig

@typing_extensions.final
class ComputeInstanceFromTemplateXNetworkInterfaceXIpv6AccessConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_IPV6_FIELD_NUMBER: builtins.int
    EXTERNAL_IPV6_PREFIX_LENGTH_FIELD_NUMBER: builtins.int
    NETWORK_TIER_FIELD_NUMBER: builtins.int
    PUBLIC_PTR_DOMAIN_NAME_FIELD_NUMBER: builtins.int
    external_ipv6: builtins.str
    external_ipv6_prefix_length: builtins.str
    network_tier: builtins.str
    public_ptr_domain_name: builtins.str
    def __init__(
        self,
        *,
        external_ipv6: builtins.str = ...,
        external_ipv6_prefix_length: builtins.str = ...,
        network_tier: builtins.str = ...,
        public_ptr_domain_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["external_ipv6", b"external_ipv6", "external_ipv6_prefix_length", b"external_ipv6_prefix_length", "network_tier", b"network_tier", "public_ptr_domain_name", b"public_ptr_domain_name"]) -> None: ...

global___ComputeInstanceFromTemplateXNetworkInterfaceXIpv6AccessConfig = ComputeInstanceFromTemplateXNetworkInterfaceXIpv6AccessConfig

@typing_extensions.final
class ComputeInstanceFromTemplateXNetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AccessConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class AliasIpRangeEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACCESS_CONFIG_FIELD_NUMBER: builtins.int
    ALIAS_IP_RANGE_FIELD_NUMBER: builtins.int
    IPV6_ACCESS_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NETWORK_IP_FIELD_NUMBER: builtins.int
    NIC_TYPE_FIELD_NUMBER: builtins.int
    QUEUE_COUNT_FIELD_NUMBER: builtins.int
    STACK_TYPE_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    SUBNETWORK_PROJECT_FIELD_NUMBER: builtins.int
    IPV6_ACCESS_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def access_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def alias_ip_range(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    ipv6_access_type: builtins.str
    name: builtins.str
    network: builtins.str
    network_ip: builtins.str
    nic_type: builtins.str
    queue_count: builtins.float
    stack_type: builtins.str
    subnetwork: builtins.str
    subnetwork_project: builtins.str
    @property
    def ipv6_access_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceFromTemplateXNetworkInterfaceXIpv6AccessConfig]: ...
    def __init__(
        self,
        *,
        access_config: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        alias_ip_range: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        ipv6_access_type: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        network_ip: builtins.str = ...,
        nic_type: builtins.str = ...,
        queue_count: builtins.float = ...,
        stack_type: builtins.str = ...,
        subnetwork: builtins.str = ...,
        subnetwork_project: builtins.str = ...,
        ipv6_access_config: collections.abc.Iterable[global___ComputeInstanceFromTemplateXNetworkInterfaceXIpv6AccessConfig] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_config", b"access_config", "alias_ip_range", b"alias_ip_range", "ipv6_access_config", b"ipv6_access_config", "ipv6_access_type", b"ipv6_access_type", "name", b"name", "network", b"network", "network_ip", b"network_ip", "nic_type", b"nic_type", "queue_count", b"queue_count", "stack_type", b"stack_type", "subnetwork", b"subnetwork", "subnetwork_project", b"subnetwork_project"]) -> None: ...

global___ComputeInstanceFromTemplateXNetworkInterface = ComputeInstanceFromTemplateXNetworkInterface

@typing_extensions.final
class ComputeInstanceFromTemplateXReservationAffinityXSpecificReservation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "values", b"values"]) -> None: ...

global___ComputeInstanceFromTemplateXReservationAffinityXSpecificReservation = ComputeInstanceFromTemplateXReservationAffinityXSpecificReservation

@typing_extensions.final
class ComputeInstanceFromTemplateXReservationAffinity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    SPECIFIC_RESERVATION_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def specific_reservation(self) -> global___ComputeInstanceFromTemplateXReservationAffinityXSpecificReservation: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        specific_reservation: global___ComputeInstanceFromTemplateXReservationAffinityXSpecificReservation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["specific_reservation", b"specific_reservation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["specific_reservation", b"specific_reservation", "type", b"type"]) -> None: ...

global___ComputeInstanceFromTemplateXReservationAffinity = ComputeInstanceFromTemplateXReservationAffinity

@typing_extensions.final
class ComputeInstanceFromTemplateXSchedulingXNodeAffinities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    key: builtins.str
    operator: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        operator: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "operator", b"operator", "values", b"values"]) -> None: ...

global___ComputeInstanceFromTemplateXSchedulingXNodeAffinities = ComputeInstanceFromTemplateXSchedulingXNodeAffinities

@typing_extensions.final
class ComputeInstanceFromTemplateXScheduling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTOMATIC_RESTART_FIELD_NUMBER: builtins.int
    INSTANCE_TERMINATION_ACTION_FIELD_NUMBER: builtins.int
    MIN_NODE_CPUS_FIELD_NUMBER: builtins.int
    ON_HOST_MAINTENANCE_FIELD_NUMBER: builtins.int
    PREEMPTIBLE_FIELD_NUMBER: builtins.int
    PROVISIONING_MODEL_FIELD_NUMBER: builtins.int
    NODE_AFFINITIES_FIELD_NUMBER: builtins.int
    automatic_restart: builtins.bool
    instance_termination_action: builtins.str
    min_node_cpus: builtins.float
    on_host_maintenance: builtins.str
    preemptible: builtins.bool
    provisioning_model: builtins.str
    @property
    def node_affinities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceFromTemplateXSchedulingXNodeAffinities]: ...
    def __init__(
        self,
        *,
        automatic_restart: builtins.bool = ...,
        instance_termination_action: builtins.str = ...,
        min_node_cpus: builtins.float = ...,
        on_host_maintenance: builtins.str = ...,
        preemptible: builtins.bool = ...,
        provisioning_model: builtins.str = ...,
        node_affinities: collections.abc.Iterable[global___ComputeInstanceFromTemplateXSchedulingXNodeAffinities] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["automatic_restart", b"automatic_restart", "instance_termination_action", b"instance_termination_action", "min_node_cpus", b"min_node_cpus", "node_affinities", b"node_affinities", "on_host_maintenance", b"on_host_maintenance", "preemptible", b"preemptible", "provisioning_model", b"provisioning_model"]) -> None: ...

global___ComputeInstanceFromTemplateXScheduling = ComputeInstanceFromTemplateXScheduling

@typing_extensions.final
class ComputeInstanceFromTemplateXShieldedInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_INTEGRITY_MONITORING_FIELD_NUMBER: builtins.int
    ENABLE_SECURE_BOOT_FIELD_NUMBER: builtins.int
    ENABLE_VTPM_FIELD_NUMBER: builtins.int
    enable_integrity_monitoring: builtins.bool
    enable_secure_boot: builtins.bool
    enable_vtpm: builtins.bool
    def __init__(
        self,
        *,
        enable_integrity_monitoring: builtins.bool = ...,
        enable_secure_boot: builtins.bool = ...,
        enable_vtpm: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_integrity_monitoring", b"enable_integrity_monitoring", "enable_secure_boot", b"enable_secure_boot", "enable_vtpm", b"enable_vtpm"]) -> None: ...

global___ComputeInstanceFromTemplateXShieldedInstanceConfig = ComputeInstanceFromTemplateXShieldedInstanceConfig

@typing_extensions.final
class ComputeInstanceFromTemplateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeInstanceFromTemplateXTimeouts = ComputeInstanceFromTemplateXTimeouts

@typing_extensions.final
class ComputeInstanceFromTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttachedDiskEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class GuestAcceleratorEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ScratchDiskEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ServiceAccountEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ALLOW_STOPPING_FOR_UPDATE_FIELD_NUMBER: builtins.int
    ATTACHED_DISK_FIELD_NUMBER: builtins.int
    CAN_IP_FORWARD_FIELD_NUMBER: builtins.int
    CPU_PLATFORM_FIELD_NUMBER: builtins.int
    CURRENT_STATUS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DESIRED_STATUS_FIELD_NUMBER: builtins.int
    ENABLE_DISPLAY_FIELD_NUMBER: builtins.int
    GUEST_ACCELERATOR_FIELD_NUMBER: builtins.int
    HOSTNAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    LABEL_FINGERPRINT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    METADATA_FINGERPRINT_FIELD_NUMBER: builtins.int
    METADATA_STARTUP_SCRIPT_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_POLICIES_FIELD_NUMBER: builtins.int
    SCRATCH_DISK_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SOURCE_INSTANCE_TEMPLATE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TAGS_FINGERPRINT_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    ADVANCED_MACHINE_FEATURES_FIELD_NUMBER: builtins.int
    BOOT_DISK_FIELD_NUMBER: builtins.int
    CONFIDENTIAL_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACE_FIELD_NUMBER: builtins.int
    RESERVATION_AFFINITY_FIELD_NUMBER: builtins.int
    SCHEDULING_FIELD_NUMBER: builtins.int
    SHIELDED_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    allow_stopping_for_update: builtins.bool
    @property
    def attached_disk(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    can_ip_forward: builtins.bool
    cpu_platform: builtins.str
    current_status: builtins.str
    deletion_protection: builtins.bool
    description: builtins.str
    desired_status: builtins.str
    enable_display: builtins.bool
    @property
    def guest_accelerator(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    hostname: builtins.str
    id: builtins.str
    instance_id: builtins.str
    label_fingerprint: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    machine_type: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    metadata_fingerprint: builtins.str
    metadata_startup_script: builtins.str
    min_cpu_platform: builtins.str
    name: builtins.str
    project: builtins.str
    @property
    def resource_policies(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def scratch_disk(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    self_link: builtins.str
    @property
    def service_account(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    source_instance_template: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    tags_fingerprint: builtins.str
    zone: builtins.str
    @property
    def advanced_machine_features(self) -> global___ComputeInstanceFromTemplateXAdvancedMachineFeatures: ...
    @property
    def boot_disk(self) -> global___ComputeInstanceFromTemplateXBootDisk: ...
    @property
    def confidential_instance_config(self) -> global___ComputeInstanceFromTemplateXConfidentialInstanceConfig: ...
    @property
    def network_interface(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceFromTemplateXNetworkInterface]: ...
    @property
    def reservation_affinity(self) -> global___ComputeInstanceFromTemplateXReservationAffinity: ...
    @property
    def scheduling(self) -> global___ComputeInstanceFromTemplateXScheduling: ...
    @property
    def shielded_instance_config(self) -> global___ComputeInstanceFromTemplateXShieldedInstanceConfig: ...
    @property
    def timeouts(self) -> global___ComputeInstanceFromTemplateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        allow_stopping_for_update: builtins.bool = ...,
        attached_disk: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        can_ip_forward: builtins.bool = ...,
        cpu_platform: builtins.str = ...,
        current_status: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
        description: builtins.str = ...,
        desired_status: builtins.str = ...,
        enable_display: builtins.bool = ...,
        guest_accelerator: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        hostname: builtins.str = ...,
        id: builtins.str = ...,
        instance_id: builtins.str = ...,
        label_fingerprint: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        machine_type: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        metadata_fingerprint: builtins.str = ...,
        metadata_startup_script: builtins.str = ...,
        min_cpu_platform: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        resource_policies: collections.abc.Iterable[builtins.str] | None = ...,
        scratch_disk: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        self_link: builtins.str = ...,
        service_account: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        source_instance_template: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        tags_fingerprint: builtins.str = ...,
        zone: builtins.str = ...,
        advanced_machine_features: global___ComputeInstanceFromTemplateXAdvancedMachineFeatures | None = ...,
        boot_disk: global___ComputeInstanceFromTemplateXBootDisk | None = ...,
        confidential_instance_config: global___ComputeInstanceFromTemplateXConfidentialInstanceConfig | None = ...,
        network_interface: collections.abc.Iterable[global___ComputeInstanceFromTemplateXNetworkInterface] | None = ...,
        reservation_affinity: global___ComputeInstanceFromTemplateXReservationAffinity | None = ...,
        scheduling: global___ComputeInstanceFromTemplateXScheduling | None = ...,
        shielded_instance_config: global___ComputeInstanceFromTemplateXShieldedInstanceConfig | None = ...,
        timeouts: global___ComputeInstanceFromTemplateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["advanced_machine_features", b"advanced_machine_features", "boot_disk", b"boot_disk", "confidential_instance_config", b"confidential_instance_config", "reservation_affinity", b"reservation_affinity", "resource_info", b"resource_info", "scheduling", b"scheduling", "shielded_instance_config", b"shielded_instance_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["advanced_machine_features", b"advanced_machine_features", "allow_stopping_for_update", b"allow_stopping_for_update", "attached_disk", b"attached_disk", "boot_disk", b"boot_disk", "can_ip_forward", b"can_ip_forward", "confidential_instance_config", b"confidential_instance_config", "cpu_platform", b"cpu_platform", "current_status", b"current_status", "deletion_protection", b"deletion_protection", "description", b"description", "desired_status", b"desired_status", "enable_display", b"enable_display", "guest_accelerator", b"guest_accelerator", "hostname", b"hostname", "id", b"id", "instance_id", b"instance_id", "label_fingerprint", b"label_fingerprint", "labels", b"labels", "machine_type", b"machine_type", "metadata", b"metadata", "metadata_fingerprint", b"metadata_fingerprint", "metadata_startup_script", b"metadata_startup_script", "min_cpu_platform", b"min_cpu_platform", "name", b"name", "network_interface", b"network_interface", "project", b"project", "reservation_affinity", b"reservation_affinity", "resource_info", b"resource_info", "resource_policies", b"resource_policies", "scheduling", b"scheduling", "scratch_disk", b"scratch_disk", "self_link", b"self_link", "service_account", b"service_account", "shielded_instance_config", b"shielded_instance_config", "source_instance_template", b"source_instance_template", "tags", b"tags", "tags_fingerprint", b"tags_fingerprint", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeInstanceFromTemplate = ComputeInstanceFromTemplate

@typing_extensions.final
class ComputeInstanceGroupXNamedPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    name: builtins.str
    port: builtins.float
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        port: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "port", b"port"]) -> None: ...

global___ComputeInstanceGroupXNamedPort = ComputeInstanceGroupXNamedPort

@typing_extensions.final
class ComputeInstanceGroupXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeInstanceGroupXTimeouts = ComputeInstanceGroupXTimeouts

@typing_extensions.final
class ComputeInstanceGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    NAMED_PORT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    network: builtins.str
    project: builtins.str
    self_link: builtins.str
    size: builtins.float
    zone: builtins.str
    @property
    def named_port(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceGroupXNamedPort]: ...
    @property
    def timeouts(self) -> global___ComputeInstanceGroupXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        instances: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        size: builtins.float = ...,
        zone: builtins.str = ...,
        named_port: collections.abc.Iterable[global___ComputeInstanceGroupXNamedPort] | None = ...,
        timeouts: global___ComputeInstanceGroupXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "id", b"id", "instances", b"instances", "name", b"name", "named_port", b"named_port", "network", b"network", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "size", b"size", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeInstanceGroup = ComputeInstanceGroup

@typing_extensions.final
class ComputeInstanceGroupManagerXAutoHealingPolicies(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_FIELD_NUMBER: builtins.int
    INITIAL_DELAY_SEC_FIELD_NUMBER: builtins.int
    health_check: builtins.str
    initial_delay_sec: builtins.float
    def __init__(
        self,
        *,
        health_check: builtins.str = ...,
        initial_delay_sec: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check", b"health_check", "initial_delay_sec", b"initial_delay_sec"]) -> None: ...

global___ComputeInstanceGroupManagerXAutoHealingPolicies = ComputeInstanceGroupManagerXAutoHealingPolicies

@typing_extensions.final
class ComputeInstanceGroupManagerXNamedPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    name: builtins.str
    port: builtins.float
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        port: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "port", b"port"]) -> None: ...

global___ComputeInstanceGroupManagerXNamedPort = ComputeInstanceGroupManagerXNamedPort

@typing_extensions.final
class ComputeInstanceGroupManagerXStatefulDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETE_RULE_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    delete_rule: builtins.str
    device_name: builtins.str
    def __init__(
        self,
        *,
        delete_rule: builtins.str = ...,
        device_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_rule", b"delete_rule", "device_name", b"device_name"]) -> None: ...

global___ComputeInstanceGroupManagerXStatefulDisk = ComputeInstanceGroupManagerXStatefulDisk

@typing_extensions.final
class ComputeInstanceGroupManagerXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeInstanceGroupManagerXTimeouts = ComputeInstanceGroupManagerXTimeouts

@typing_extensions.final
class ComputeInstanceGroupManagerXUpdatePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_SURGE_FIXED_FIELD_NUMBER: builtins.int
    MAX_SURGE_PERCENT_FIELD_NUMBER: builtins.int
    MAX_UNAVAILABLE_FIXED_FIELD_NUMBER: builtins.int
    MAX_UNAVAILABLE_PERCENT_FIELD_NUMBER: builtins.int
    MINIMAL_ACTION_FIELD_NUMBER: builtins.int
    MOST_DISRUPTIVE_ALLOWED_ACTION_FIELD_NUMBER: builtins.int
    REPLACEMENT_METHOD_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    max_surge_fixed: builtins.float
    max_surge_percent: builtins.float
    max_unavailable_fixed: builtins.float
    max_unavailable_percent: builtins.float
    minimal_action: builtins.str
    most_disruptive_allowed_action: builtins.str
    replacement_method: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        max_surge_fixed: builtins.float = ...,
        max_surge_percent: builtins.float = ...,
        max_unavailable_fixed: builtins.float = ...,
        max_unavailable_percent: builtins.float = ...,
        minimal_action: builtins.str = ...,
        most_disruptive_allowed_action: builtins.str = ...,
        replacement_method: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_surge_fixed", b"max_surge_fixed", "max_surge_percent", b"max_surge_percent", "max_unavailable_fixed", b"max_unavailable_fixed", "max_unavailable_percent", b"max_unavailable_percent", "minimal_action", b"minimal_action", "most_disruptive_allowed_action", b"most_disruptive_allowed_action", "replacement_method", b"replacement_method", "type", b"type"]) -> None: ...

global___ComputeInstanceGroupManagerXUpdatePolicy = ComputeInstanceGroupManagerXUpdatePolicy

@typing_extensions.final
class ComputeInstanceGroupManagerXVersionXTargetSize(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIXED_FIELD_NUMBER: builtins.int
    PERCENT_FIELD_NUMBER: builtins.int
    fixed: builtins.float
    percent: builtins.float
    def __init__(
        self,
        *,
        fixed: builtins.float = ...,
        percent: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed", b"fixed", "percent", b"percent"]) -> None: ...

global___ComputeInstanceGroupManagerXVersionXTargetSize = ComputeInstanceGroupManagerXVersionXTargetSize

@typing_extensions.final
class ComputeInstanceGroupManagerXVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_TEMPLATE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TARGET_SIZE_FIELD_NUMBER: builtins.int
    instance_template: builtins.str
    name: builtins.str
    @property
    def target_size(self) -> global___ComputeInstanceGroupManagerXVersionXTargetSize: ...
    def __init__(
        self,
        *,
        instance_template: builtins.str = ...,
        name: builtins.str = ...,
        target_size: global___ComputeInstanceGroupManagerXVersionXTargetSize | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["target_size", b"target_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_template", b"instance_template", "name", b"name", "target_size", b"target_size"]) -> None: ...

global___ComputeInstanceGroupManagerXVersion = ComputeInstanceGroupManagerXVersion

@typing_extensions.final
class ComputeInstanceGroupManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class StatusEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BASE_INSTANCE_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FINGERPRINT_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_GROUP_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TARGET_POOLS_FIELD_NUMBER: builtins.int
    TARGET_SIZE_FIELD_NUMBER: builtins.int
    WAIT_FOR_INSTANCES_FIELD_NUMBER: builtins.int
    WAIT_FOR_INSTANCES_STATUS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    AUTO_HEALING_POLICIES_FIELD_NUMBER: builtins.int
    NAMED_PORT_FIELD_NUMBER: builtins.int
    STATEFUL_DISK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    UPDATE_POLICY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    base_instance_name: builtins.str
    description: builtins.str
    fingerprint: builtins.str
    id: builtins.str
    instance_group: builtins.str
    name: builtins.str
    operation: builtins.str
    project: builtins.str
    self_link: builtins.str
    @property
    def status(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def target_pools(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    target_size: builtins.float
    wait_for_instances: builtins.bool
    wait_for_instances_status: builtins.str
    zone: builtins.str
    @property
    def auto_healing_policies(self) -> global___ComputeInstanceGroupManagerXAutoHealingPolicies: ...
    @property
    def named_port(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceGroupManagerXNamedPort]: ...
    @property
    def stateful_disk(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceGroupManagerXStatefulDisk]: ...
    @property
    def timeouts(self) -> global___ComputeInstanceGroupManagerXTimeouts: ...
    @property
    def update_policy(self) -> global___ComputeInstanceGroupManagerXUpdatePolicy: ...
    @property
    def version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceGroupManagerXVersion]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        base_instance_name: builtins.str = ...,
        description: builtins.str = ...,
        fingerprint: builtins.str = ...,
        id: builtins.str = ...,
        instance_group: builtins.str = ...,
        name: builtins.str = ...,
        operation: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        status: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        target_pools: collections.abc.Iterable[builtins.str] | None = ...,
        target_size: builtins.float = ...,
        wait_for_instances: builtins.bool = ...,
        wait_for_instances_status: builtins.str = ...,
        zone: builtins.str = ...,
        auto_healing_policies: global___ComputeInstanceGroupManagerXAutoHealingPolicies | None = ...,
        named_port: collections.abc.Iterable[global___ComputeInstanceGroupManagerXNamedPort] | None = ...,
        stateful_disk: collections.abc.Iterable[global___ComputeInstanceGroupManagerXStatefulDisk] | None = ...,
        timeouts: global___ComputeInstanceGroupManagerXTimeouts | None = ...,
        update_policy: global___ComputeInstanceGroupManagerXUpdatePolicy | None = ...,
        version: collections.abc.Iterable[global___ComputeInstanceGroupManagerXVersion] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_healing_policies", b"auto_healing_policies", "resource_info", b"resource_info", "timeouts", b"timeouts", "update_policy", b"update_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_healing_policies", b"auto_healing_policies", "base_instance_name", b"base_instance_name", "description", b"description", "fingerprint", b"fingerprint", "id", b"id", "instance_group", b"instance_group", "name", b"name", "named_port", b"named_port", "operation", b"operation", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "stateful_disk", b"stateful_disk", "status", b"status", "target_pools", b"target_pools", "target_size", b"target_size", "timeouts", b"timeouts", "update_policy", b"update_policy", "version", b"version", "wait_for_instances", b"wait_for_instances", "wait_for_instances_status", b"wait_for_instances_status", "zone", b"zone"]) -> None: ...

global___ComputeInstanceGroupManager = ComputeInstanceGroupManager

@typing_extensions.final
class ComputeInstanceGroupNamedPortXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeInstanceGroupNamedPortXTimeouts = ComputeInstanceGroupNamedPortXTimeouts

@typing_extensions.final
class ComputeInstanceGroupNamedPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    group: builtins.str
    id: builtins.str
    name: builtins.str
    port: builtins.float
    project: builtins.str
    zone: builtins.str
    @property
    def timeouts(self) -> global___ComputeInstanceGroupNamedPortXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        group: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        port: builtins.float = ...,
        project: builtins.str = ...,
        zone: builtins.str = ...,
        timeouts: global___ComputeInstanceGroupNamedPortXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group", b"group", "id", b"id", "name", b"name", "port", b"port", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeInstanceGroupNamedPort = ComputeInstanceGroupNamedPort

@typing_extensions.final
class ComputeInstanceIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeInstanceIamBindingXCondition = ComputeInstanceIamBindingXCondition

@typing_extensions.final
class ComputeInstanceIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance_name: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    zone: builtins.str
    @property
    def condition(self) -> global___ComputeInstanceIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance_name: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        zone: builtins.str = ...,
        condition: global___ComputeInstanceIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "instance_name", b"instance_name", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role", "zone", b"zone"]) -> None: ...

global___ComputeInstanceIamBinding = ComputeInstanceIamBinding

@typing_extensions.final
class ComputeInstanceIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeInstanceIamMemberXCondition = ComputeInstanceIamMemberXCondition

@typing_extensions.final
class ComputeInstanceIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance_name: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    zone: builtins.str
    @property
    def condition(self) -> global___ComputeInstanceIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance_name: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        zone: builtins.str = ...,
        condition: global___ComputeInstanceIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "instance_name", b"instance_name", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role", "zone", b"zone"]) -> None: ...

global___ComputeInstanceIamMember = ComputeInstanceIamMember

@typing_extensions.final
class ComputeInstanceIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_NAME_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    instance_name: builtins.str
    policy_data: builtins.str
    project: builtins.str
    zone: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        instance_name: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        zone: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "instance_name", b"instance_name", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info", "zone", b"zone"]) -> None: ...

global___ComputeInstanceIamPolicy = ComputeInstanceIamPolicy

@typing_extensions.final
class ComputeInstanceTemplateXAdvancedMachineFeatures(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_NESTED_VIRTUALIZATION_FIELD_NUMBER: builtins.int
    THREADS_PER_CORE_FIELD_NUMBER: builtins.int
    enable_nested_virtualization: builtins.bool
    threads_per_core: builtins.float
    def __init__(
        self,
        *,
        enable_nested_virtualization: builtins.bool = ...,
        threads_per_core: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_nested_virtualization", b"enable_nested_virtualization", "threads_per_core", b"threads_per_core"]) -> None: ...

global___ComputeInstanceTemplateXAdvancedMachineFeatures = ComputeInstanceTemplateXAdvancedMachineFeatures

@typing_extensions.final
class ComputeInstanceTemplateXConfidentialInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_CONFIDENTIAL_COMPUTE_FIELD_NUMBER: builtins.int
    enable_confidential_compute: builtins.bool
    def __init__(
        self,
        *,
        enable_confidential_compute: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_confidential_compute", b"enable_confidential_compute"]) -> None: ...

global___ComputeInstanceTemplateXConfidentialInstanceConfig = ComputeInstanceTemplateXConfidentialInstanceConfig

@typing_extensions.final
class ComputeInstanceTemplateXDiskXDiskEncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_SELF_LINK_FIELD_NUMBER: builtins.int
    kms_key_self_link: builtins.str
    def __init__(
        self,
        *,
        kms_key_self_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_self_link", b"kms_key_self_link"]) -> None: ...

global___ComputeInstanceTemplateXDiskXDiskEncryptionKey = ComputeInstanceTemplateXDiskXDiskEncryptionKey

@typing_extensions.final
class ComputeInstanceTemplateXDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AUTO_DELETE_FIELD_NUMBER: builtins.int
    BOOT_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    DISK_NAME_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    DISK_TYPE_FIELD_NUMBER: builtins.int
    INTERFACE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    RESOURCE_POLICIES_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    SOURCE_IMAGE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DISK_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    auto_delete: builtins.bool
    boot: builtins.bool
    device_name: builtins.str
    disk_name: builtins.str
    disk_size_gb: builtins.float
    disk_type: builtins.str
    interface: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    mode: builtins.str
    @property
    def resource_policies(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    source: builtins.str
    source_image: builtins.str
    type: builtins.str
    @property
    def disk_encryption_key(self) -> global___ComputeInstanceTemplateXDiskXDiskEncryptionKey: ...
    def __init__(
        self,
        *,
        auto_delete: builtins.bool = ...,
        boot: builtins.bool = ...,
        device_name: builtins.str = ...,
        disk_name: builtins.str = ...,
        disk_size_gb: builtins.float = ...,
        disk_type: builtins.str = ...,
        interface: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        mode: builtins.str = ...,
        resource_policies: collections.abc.Iterable[builtins.str] | None = ...,
        source: builtins.str = ...,
        source_image: builtins.str = ...,
        type: builtins.str = ...,
        disk_encryption_key: global___ComputeInstanceTemplateXDiskXDiskEncryptionKey | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["disk_encryption_key", b"disk_encryption_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_delete", b"auto_delete", "boot", b"boot", "device_name", b"device_name", "disk_encryption_key", b"disk_encryption_key", "disk_name", b"disk_name", "disk_size_gb", b"disk_size_gb", "disk_type", b"disk_type", "interface", b"interface", "labels", b"labels", "mode", b"mode", "resource_policies", b"resource_policies", "source", b"source", "source_image", b"source_image", "type", b"type"]) -> None: ...

global___ComputeInstanceTemplateXDisk = ComputeInstanceTemplateXDisk

@typing_extensions.final
class ComputeInstanceTemplateXGuestAccelerator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    count: builtins.float
    type: builtins.str
    def __init__(
        self,
        *,
        count: builtins.float = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "type", b"type"]) -> None: ...

global___ComputeInstanceTemplateXGuestAccelerator = ComputeInstanceTemplateXGuestAccelerator

@typing_extensions.final
class ComputeInstanceTemplateXNetworkInterfaceXAccessConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAT_IP_FIELD_NUMBER: builtins.int
    NETWORK_TIER_FIELD_NUMBER: builtins.int
    PUBLIC_PTR_DOMAIN_NAME_FIELD_NUMBER: builtins.int
    nat_ip: builtins.str
    network_tier: builtins.str
    public_ptr_domain_name: builtins.str
    def __init__(
        self,
        *,
        nat_ip: builtins.str = ...,
        network_tier: builtins.str = ...,
        public_ptr_domain_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["nat_ip", b"nat_ip", "network_tier", b"network_tier", "public_ptr_domain_name", b"public_ptr_domain_name"]) -> None: ...

global___ComputeInstanceTemplateXNetworkInterfaceXAccessConfig = ComputeInstanceTemplateXNetworkInterfaceXAccessConfig

@typing_extensions.final
class ComputeInstanceTemplateXNetworkInterfaceXAliasIpRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_CIDR_RANGE_FIELD_NUMBER: builtins.int
    SUBNETWORK_RANGE_NAME_FIELD_NUMBER: builtins.int
    ip_cidr_range: builtins.str
    subnetwork_range_name: builtins.str
    def __init__(
        self,
        *,
        ip_cidr_range: builtins.str = ...,
        subnetwork_range_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_cidr_range", b"ip_cidr_range", "subnetwork_range_name", b"subnetwork_range_name"]) -> None: ...

global___ComputeInstanceTemplateXNetworkInterfaceXAliasIpRange = ComputeInstanceTemplateXNetworkInterfaceXAliasIpRange

@typing_extensions.final
class ComputeInstanceTemplateXNetworkInterfaceXIpv6AccessConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_IPV6_FIELD_NUMBER: builtins.int
    EXTERNAL_IPV6_PREFIX_LENGTH_FIELD_NUMBER: builtins.int
    NETWORK_TIER_FIELD_NUMBER: builtins.int
    PUBLIC_PTR_DOMAIN_NAME_FIELD_NUMBER: builtins.int
    external_ipv6: builtins.str
    external_ipv6_prefix_length: builtins.str
    network_tier: builtins.str
    public_ptr_domain_name: builtins.str
    def __init__(
        self,
        *,
        external_ipv6: builtins.str = ...,
        external_ipv6_prefix_length: builtins.str = ...,
        network_tier: builtins.str = ...,
        public_ptr_domain_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["external_ipv6", b"external_ipv6", "external_ipv6_prefix_length", b"external_ipv6_prefix_length", "network_tier", b"network_tier", "public_ptr_domain_name", b"public_ptr_domain_name"]) -> None: ...

global___ComputeInstanceTemplateXNetworkInterfaceXIpv6AccessConfig = ComputeInstanceTemplateXNetworkInterfaceXIpv6AccessConfig

@typing_extensions.final
class ComputeInstanceTemplateXNetworkInterface(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IPV6_ACCESS_TYPE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NETWORK_IP_FIELD_NUMBER: builtins.int
    NIC_TYPE_FIELD_NUMBER: builtins.int
    QUEUE_COUNT_FIELD_NUMBER: builtins.int
    STACK_TYPE_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    SUBNETWORK_PROJECT_FIELD_NUMBER: builtins.int
    ACCESS_CONFIG_FIELD_NUMBER: builtins.int
    ALIAS_IP_RANGE_FIELD_NUMBER: builtins.int
    IPV6_ACCESS_CONFIG_FIELD_NUMBER: builtins.int
    ipv6_access_type: builtins.str
    name: builtins.str
    network: builtins.str
    network_ip: builtins.str
    nic_type: builtins.str
    queue_count: builtins.float
    stack_type: builtins.str
    subnetwork: builtins.str
    subnetwork_project: builtins.str
    @property
    def access_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceTemplateXNetworkInterfaceXAccessConfig]: ...
    @property
    def alias_ip_range(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceTemplateXNetworkInterfaceXAliasIpRange]: ...
    @property
    def ipv6_access_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceTemplateXNetworkInterfaceXIpv6AccessConfig]: ...
    def __init__(
        self,
        *,
        ipv6_access_type: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        network_ip: builtins.str = ...,
        nic_type: builtins.str = ...,
        queue_count: builtins.float = ...,
        stack_type: builtins.str = ...,
        subnetwork: builtins.str = ...,
        subnetwork_project: builtins.str = ...,
        access_config: collections.abc.Iterable[global___ComputeInstanceTemplateXNetworkInterfaceXAccessConfig] | None = ...,
        alias_ip_range: collections.abc.Iterable[global___ComputeInstanceTemplateXNetworkInterfaceXAliasIpRange] | None = ...,
        ipv6_access_config: collections.abc.Iterable[global___ComputeInstanceTemplateXNetworkInterfaceXIpv6AccessConfig] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_config", b"access_config", "alias_ip_range", b"alias_ip_range", "ipv6_access_config", b"ipv6_access_config", "ipv6_access_type", b"ipv6_access_type", "name", b"name", "network", b"network", "network_ip", b"network_ip", "nic_type", b"nic_type", "queue_count", b"queue_count", "stack_type", b"stack_type", "subnetwork", b"subnetwork", "subnetwork_project", b"subnetwork_project"]) -> None: ...

global___ComputeInstanceTemplateXNetworkInterface = ComputeInstanceTemplateXNetworkInterface

@typing_extensions.final
class ComputeInstanceTemplateXReservationAffinityXSpecificReservation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    key: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "values", b"values"]) -> None: ...

global___ComputeInstanceTemplateXReservationAffinityXSpecificReservation = ComputeInstanceTemplateXReservationAffinityXSpecificReservation

@typing_extensions.final
class ComputeInstanceTemplateXReservationAffinity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    SPECIFIC_RESERVATION_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def specific_reservation(self) -> global___ComputeInstanceTemplateXReservationAffinityXSpecificReservation: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        specific_reservation: global___ComputeInstanceTemplateXReservationAffinityXSpecificReservation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["specific_reservation", b"specific_reservation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["specific_reservation", b"specific_reservation", "type", b"type"]) -> None: ...

global___ComputeInstanceTemplateXReservationAffinity = ComputeInstanceTemplateXReservationAffinity

@typing_extensions.final
class ComputeInstanceTemplateXSchedulingXNodeAffinities(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    key: builtins.str
    operator: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        operator: builtins.str = ...,
        values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "operator", b"operator", "values", b"values"]) -> None: ...

global___ComputeInstanceTemplateXSchedulingXNodeAffinities = ComputeInstanceTemplateXSchedulingXNodeAffinities

@typing_extensions.final
class ComputeInstanceTemplateXScheduling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTOMATIC_RESTART_FIELD_NUMBER: builtins.int
    INSTANCE_TERMINATION_ACTION_FIELD_NUMBER: builtins.int
    MIN_NODE_CPUS_FIELD_NUMBER: builtins.int
    ON_HOST_MAINTENANCE_FIELD_NUMBER: builtins.int
    PREEMPTIBLE_FIELD_NUMBER: builtins.int
    PROVISIONING_MODEL_FIELD_NUMBER: builtins.int
    NODE_AFFINITIES_FIELD_NUMBER: builtins.int
    automatic_restart: builtins.bool
    instance_termination_action: builtins.str
    min_node_cpus: builtins.float
    on_host_maintenance: builtins.str
    preemptible: builtins.bool
    provisioning_model: builtins.str
    @property
    def node_affinities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceTemplateXSchedulingXNodeAffinities]: ...
    def __init__(
        self,
        *,
        automatic_restart: builtins.bool = ...,
        instance_termination_action: builtins.str = ...,
        min_node_cpus: builtins.float = ...,
        on_host_maintenance: builtins.str = ...,
        preemptible: builtins.bool = ...,
        provisioning_model: builtins.str = ...,
        node_affinities: collections.abc.Iterable[global___ComputeInstanceTemplateXSchedulingXNodeAffinities] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["automatic_restart", b"automatic_restart", "instance_termination_action", b"instance_termination_action", "min_node_cpus", b"min_node_cpus", "node_affinities", b"node_affinities", "on_host_maintenance", b"on_host_maintenance", "preemptible", b"preemptible", "provisioning_model", b"provisioning_model"]) -> None: ...

global___ComputeInstanceTemplateXScheduling = ComputeInstanceTemplateXScheduling

@typing_extensions.final
class ComputeInstanceTemplateXServiceAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAIL_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    email: builtins.str
    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        email: builtins.str = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["email", b"email", "scopes", b"scopes"]) -> None: ...

global___ComputeInstanceTemplateXServiceAccount = ComputeInstanceTemplateXServiceAccount

@typing_extensions.final
class ComputeInstanceTemplateXShieldedInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_INTEGRITY_MONITORING_FIELD_NUMBER: builtins.int
    ENABLE_SECURE_BOOT_FIELD_NUMBER: builtins.int
    ENABLE_VTPM_FIELD_NUMBER: builtins.int
    enable_integrity_monitoring: builtins.bool
    enable_secure_boot: builtins.bool
    enable_vtpm: builtins.bool
    def __init__(
        self,
        *,
        enable_integrity_monitoring: builtins.bool = ...,
        enable_secure_boot: builtins.bool = ...,
        enable_vtpm: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable_integrity_monitoring", b"enable_integrity_monitoring", "enable_secure_boot", b"enable_secure_boot", "enable_vtpm", b"enable_vtpm"]) -> None: ...

global___ComputeInstanceTemplateXShieldedInstanceConfig = ComputeInstanceTemplateXShieldedInstanceConfig

@typing_extensions.final
class ComputeInstanceTemplateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeInstanceTemplateXTimeouts = ComputeInstanceTemplateXTimeouts

@typing_extensions.final
class ComputeInstanceTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CAN_IP_FORWARD_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    METADATA_FINGERPRINT_FIELD_NUMBER: builtins.int
    METADATA_STARTUP_SCRIPT_FIELD_NUMBER: builtins.int
    MIN_CPU_PLATFORM_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAME_PREFIX_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TAGS_FINGERPRINT_FIELD_NUMBER: builtins.int
    ADVANCED_MACHINE_FEATURES_FIELD_NUMBER: builtins.int
    CONFIDENTIAL_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    DISK_FIELD_NUMBER: builtins.int
    GUEST_ACCELERATOR_FIELD_NUMBER: builtins.int
    NETWORK_INTERFACE_FIELD_NUMBER: builtins.int
    RESERVATION_AFFINITY_FIELD_NUMBER: builtins.int
    SCHEDULING_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SHIELDED_INSTANCE_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    can_ip_forward: builtins.bool
    description: builtins.str
    id: builtins.str
    instance_description: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    machine_type: builtins.str
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    metadata_fingerprint: builtins.str
    metadata_startup_script: builtins.str
    min_cpu_platform: builtins.str
    name: builtins.str
    name_prefix: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    tags_fingerprint: builtins.str
    @property
    def advanced_machine_features(self) -> global___ComputeInstanceTemplateXAdvancedMachineFeatures: ...
    @property
    def confidential_instance_config(self) -> global___ComputeInstanceTemplateXConfidentialInstanceConfig: ...
    @property
    def disk(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceTemplateXDisk]: ...
    @property
    def guest_accelerator(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceTemplateXGuestAccelerator]: ...
    @property
    def network_interface(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeInstanceTemplateXNetworkInterface]: ...
    @property
    def reservation_affinity(self) -> global___ComputeInstanceTemplateXReservationAffinity: ...
    @property
    def scheduling(self) -> global___ComputeInstanceTemplateXScheduling: ...
    @property
    def service_account(self) -> global___ComputeInstanceTemplateXServiceAccount: ...
    @property
    def shielded_instance_config(self) -> global___ComputeInstanceTemplateXShieldedInstanceConfig: ...
    @property
    def timeouts(self) -> global___ComputeInstanceTemplateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        can_ip_forward: builtins.bool = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        instance_description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        machine_type: builtins.str = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        metadata_fingerprint: builtins.str = ...,
        metadata_startup_script: builtins.str = ...,
        min_cpu_platform: builtins.str = ...,
        name: builtins.str = ...,
        name_prefix: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        tags_fingerprint: builtins.str = ...,
        advanced_machine_features: global___ComputeInstanceTemplateXAdvancedMachineFeatures | None = ...,
        confidential_instance_config: global___ComputeInstanceTemplateXConfidentialInstanceConfig | None = ...,
        disk: collections.abc.Iterable[global___ComputeInstanceTemplateXDisk] | None = ...,
        guest_accelerator: collections.abc.Iterable[global___ComputeInstanceTemplateXGuestAccelerator] | None = ...,
        network_interface: collections.abc.Iterable[global___ComputeInstanceTemplateXNetworkInterface] | None = ...,
        reservation_affinity: global___ComputeInstanceTemplateXReservationAffinity | None = ...,
        scheduling: global___ComputeInstanceTemplateXScheduling | None = ...,
        service_account: global___ComputeInstanceTemplateXServiceAccount | None = ...,
        shielded_instance_config: global___ComputeInstanceTemplateXShieldedInstanceConfig | None = ...,
        timeouts: global___ComputeInstanceTemplateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["advanced_machine_features", b"advanced_machine_features", "confidential_instance_config", b"confidential_instance_config", "reservation_affinity", b"reservation_affinity", "resource_info", b"resource_info", "scheduling", b"scheduling", "service_account", b"service_account", "shielded_instance_config", b"shielded_instance_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["advanced_machine_features", b"advanced_machine_features", "can_ip_forward", b"can_ip_forward", "confidential_instance_config", b"confidential_instance_config", "description", b"description", "disk", b"disk", "guest_accelerator", b"guest_accelerator", "id", b"id", "instance_description", b"instance_description", "labels", b"labels", "machine_type", b"machine_type", "metadata", b"metadata", "metadata_fingerprint", b"metadata_fingerprint", "metadata_startup_script", b"metadata_startup_script", "min_cpu_platform", b"min_cpu_platform", "name", b"name", "name_prefix", b"name_prefix", "network_interface", b"network_interface", "project", b"project", "region", b"region", "reservation_affinity", b"reservation_affinity", "resource_info", b"resource_info", "scheduling", b"scheduling", "self_link", b"self_link", "service_account", b"service_account", "shielded_instance_config", b"shielded_instance_config", "tags", b"tags", "tags_fingerprint", b"tags_fingerprint", "timeouts", b"timeouts"]) -> None: ...

global___ComputeInstanceTemplate = ComputeInstanceTemplate



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_privateLinkServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_LINK_SERVICES_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICES_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def private_link_services(self) -> global___PrivateLinkServices: ...
    @property
    def private_link_services_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateLinkServicesPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        private_link_services: global___PrivateLinkServices | None = ...,
        private_link_services_private_endpoint_connections: collections.abc.Iterable[global___PrivateLinkServicesPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_link_services", b"private_link_services"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["private_link_services", b"private_link_services", "private_link_services_private_endpoint_connections", b"private_link_services_private_endpoint_connections"]) -> None: ...

global___Microsoft_Network_privateLinkServices = Microsoft_Network_privateLinkServices

@typing_extensions.final
class PrivateLinkServicesPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def private_link_service_connection_state(self) -> global___PrivateLinkServiceConnectionState: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        private_link_service_connection_state: global___PrivateLinkServiceConnectionState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> None: ...

global___PrivateLinkServicesPrivateEndpointConnections = PrivateLinkServicesPrivateEndpointConnections

@typing_extensions.final
class PrivateLinkServiceConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    status: builtins.str
    description: builtins.str
    actions_required: builtins.str
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        description: builtins.str = ...,
        actions_required: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___PrivateLinkServiceConnectionState = PrivateLinkServiceConnectionState

@typing_extensions.final
class PrivateLinkServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    EXTENDED_LOCATION_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_FRONTEND_IP_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    IP_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    VISIBILITY_FIELD_NUMBER: builtins.int
    AUTO_APPROVAL_FIELD_NUMBER: builtins.int
    FQDNS_FIELD_NUMBER: builtins.int
    ENABLE_PROXY_PROTOCOL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def extended_location(self) -> global___ExtendedLocation: ...
    @property
    def load_balancer_frontend_ip_configurations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ip_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateLinkServiceIpConfiguration]: ...
    @property
    def visibility(self) -> global___PrivateLinkServicePropertiesVisibility: ...
    @property
    def auto_approval(self) -> global___PrivateLinkServicePropertiesAutoApproval: ...
    @property
    def fqdns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    enable_proxy_protocol: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        extended_location: global___ExtendedLocation | None = ...,
        load_balancer_frontend_ip_configurations: collections.abc.Iterable[builtins.str] | None = ...,
        ip_configurations: collections.abc.Iterable[global___PrivateLinkServiceIpConfiguration] | None = ...,
        visibility: global___PrivateLinkServicePropertiesVisibility | None = ...,
        auto_approval: global___PrivateLinkServicePropertiesAutoApproval | None = ...,
        fqdns: collections.abc.Iterable[builtins.str] | None = ...,
        enable_proxy_protocol: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auto_approval", b"auto_approval", "extended_location", b"extended_location", "resource_info", b"resource_info", "visibility", b"visibility"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_approval", b"auto_approval", "enable_proxy_protocol", b"enable_proxy_protocol", "extended_location", b"extended_location", "fqdns", b"fqdns", "ip_configurations", b"ip_configurations", "load_balancer_frontend_ip_configurations", b"load_balancer_frontend_ip_configurations", "location", b"location", "name", b"name", "resource_info", b"resource_info", "tags", b"tags", "visibility", b"visibility"]) -> None: ...

global___PrivateLinkServices = PrivateLinkServices

@typing_extensions.final
class PrivateLinkServicePropertiesAutoApproval(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
    @property
    def subscriptions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        subscriptions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["subscriptions", b"subscriptions"]) -> None: ...

global___PrivateLinkServicePropertiesAutoApproval = PrivateLinkServicePropertiesAutoApproval

@typing_extensions.final
class PrivateLinkServicePropertiesVisibility(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
    @property
    def subscriptions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        subscriptions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["subscriptions", b"subscriptions"]) -> None: ...

global___PrivateLinkServicePropertiesVisibility = PrivateLinkServicePropertiesVisibility

@typing_extensions.final
class PrivateLinkServiceIpConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_IP_ADDRESS_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ALLOCATION_METHOD_FIELD_NUMBER: builtins.int
    SUBNET_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    PRIVATE_IP_ADDRESS_VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    private_ip_address: builtins.str
    private_ip_allocation_method: builtins.str
    subnet: builtins.str
    primary: builtins.bool
    private_ip_address_version: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        private_ip_address: builtins.str = ...,
        private_ip_allocation_method: builtins.str = ...,
        subnet: builtins.str = ...,
        primary: builtins.bool = ...,
        private_ip_address_version: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "primary", b"primary", "private_ip_address", b"private_ip_address", "private_ip_address_version", b"private_ip_address_version", "private_ip_allocation_method", b"private_ip_allocation_method", "subnet", b"subnet"]) -> None: ...

global___PrivateLinkServiceIpConfiguration = PrivateLinkServiceIpConfiguration

@typing_extensions.final
class ExtendedLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___ExtendedLocation = ExtendedLocation
